function state = DLST_initialize(image, region)
    
    % get region
    state.region = region;

    % getOpts
    state.opts = DLST.getOpts();
    
    % override image size
    state.opts.imageSize = size(image);
     
    % load network
    [state.lnet, state.cnet] = DLST.loadNet(state.opts);
    
    if state.opts.useGpu
        state.lnet.feat.move('gpu');
        state.lnet.trac.move('gpu');
        state.cnet.feat.move('gpu');
        state.cnet.trac.move('gpu');
    end
    
    if state.opts.useBBReg
        state.regressor = BoundingBox.train(state.cnet.feat, image, state.region, state.opts);
    end
    
    % process clfNet
    positives = Sampler.getPositives('gaussian', state.region, ...
                                     state.opts.initNumPos, ...
                                     state.opts.imageSize, ...
                                     state.opts.scaleFactor, 0.1, 5, ...
                                     state.opts.initPosThre);
    negatives = Sampler.getNegatives('none', state.region, ...
                                     state.opts.initNumNeg, ...
                                     state.opts.imageSize, ...
                                     state.opts.scaleFactor, 1, 10, ...
                                     state.opts.initNegThre, true);
                                 
    samples = [positives; negatives];
    
    posIndex = 1:size(positives, 1);
    negIndex = (1:size(negatives,1)) + size(positives,1);
    
    patches = Utility.getPatches(image, samples, state.opts);
    features = Network.forward(state.cnet.feat, {patches - 128}, state.opts, 'feature');
    posFeats = features(:, :, :, posIndex);
    negFeats = features(:, :, :, negIndex);
    
    state.cnet.trac = Network.trainCNet(state.cnet.trac, [], ...
                                        {posFeats}, {negFeats}, state.opts,...
                                        'maxIters', state.opts.initMaxIters, ...
                                        'learningRate', state.opts.learningRate);
    
    % process locNet
    [patches, labels, instanceWeights] = DLST.getSearchRegions(image, positives(1:10:end, :), state.opts);
    state.cosWindow = single(hann(state.opts.labelSize) * hann(state.opts.labelSize)');
    features = Network.forward(state.lnet.feat, {patches - 128}, state.opts, 'feature');
    features = bsxfun(@times, features, state.cosWindow);
    state.lnet.trac = Network.trainLNet(state.lnet.trac, [], features, ....
                                        labels, instanceWeights, state.opts, ...
                                        'maxIters', state.opts.initMaxIters, ...
                                        'learningRate', state.opts.learningRate, ...
                                        'batchSize', state.opts.locBatchSize);
     
    % for locNet
    state.lnetFeats = cell(1, 1);
    state.lnetLabel = cell(1, 1);
    state.lnetInstW = cell(1, 1);
    state.lnetFeats{1} = features;
    state.lnetLabel{1} = labels;
    state.lnetInstW{1} = instanceWeights;
    
    % collect feature
    state.cnetPos = cell(1, 1);
    state.cnetNeg = cell(1, 1);
    
    negatives = Sampler.getNegatives('uniform', state.region, ...
                                     state.opts.updateNumNeg, ...
                                     state.opts.imageSize, ...
                                     state.opts.scaleFactor, 2, 5, ...
                                     state.opts.initNegThre, false);
    patches = Utility.getPatches(image, negatives, state.opts);
    features = Network.forward(state.cnet.feat, {patches - 128}, state.opts, 'feature');
    
    state.cnetPos{1} = posFeats;
    state.cnetNeg{1} = features;
    
    state.success = 1;
    state.frame = 1;
    state.transF = state.opts.transF;
    state.scaleF = state.opts.scaleF;
  
end