function state = DLST_update(image, state)

    state.frame = state.frame + 1;

    currTrkPos = state.region;

    [patch, alignedPos, cropInfo] = ...
        Utility.getSearchRegion(image, currTrkPos, state.opts);
        
    feature = Network.forward(state.lnet.feat, {patch - 128}, state.opts, 'feature');
    feature = bsxfun(@times, feature, state.cosWindow);
    response = Network.forward(state.lnet.trac, {feature}, state.opts, 'prediction');
    response = squeeze(response(:,:,2));
    responseUp = cv.resize(response, [state.opts.labelSize state.opts.labelSize]*2, ...
        'Interpolation', 'Cubic');
            
    maxVal = max(responseUp(:));
    if maxVal > 0
        [maxr, maxc] = find(responseUp == max(responseUp(:)), 1);
        trans = [maxr maxc] - round(state.opts.labelSize*2) / 2;
        currLocPos = [trans(2) * state.opts.locTotalStride/2 + alignedPos(1), ...
                      trans(1) * state.opts.locTotalStride/2 + alignedPos(2), ...
                      alignedPos(3:4)];
        currLocPos = Utility.getAlignedBBoxBack(currLocPos, cropInfo);
    else
        currLocPos = currTrkPos;
    end

    samples = [Sampler.gen_samples('gaussian', currTrkPos, ...
                                   round(state.opts.numCandidates/2), ...
                                   state.opts.imageSize, ...
                                   state.opts.scaleFactor, ...
                                   state.transF, state.scaleF);
               Sampler.gen_samples('gaussian', currLocPos, ...
                                   round(state.opts.numCandidates/2), ...
                                   state.opts.imageSize, ...
                                   state.opts.scaleFactor, ...
                                   state.opts.transF, ...
                                   state.opts.scaleF)];                   
        
    patches = Utility.getPatches(image, samples, state.opts);
    features = Network.forward(state.cnet.feat, {patches - 128}, state.opts, 'feature');
    response = Network.forward(state.cnet.trac, {features}, state.opts, 'prediction');
    response = squeeze(response(:,:,2,:));

    [scores, idx] = sort(response, 'descend');
    trkScore = mean(scores(1:5));
    trkPos = mean(samples(idx(1:5), :), 1);
    currTrkPos = trkPos;
    
    if(trkScore < 0)
        state.transF = min(1.5, 1.1*state.transF);
    else
        state.transF = state.opts.transF;
    end
    
    % bbox regression
    if (state.opts.useBBReg && trkScore > 0)
        currTrkPos = BoundingBox.predict(state.regressor, features(:,:,:,idx(1:5)), samples(idx(1:5), :));
    end
        
    % collect data
    if (trkScore > 0 || state.frame <= 3)
        % for clfNet
        positives = Sampler.getPositives('gaussian', trkPos, ...
                                         state.opts.updateNumPos, ...
                                         state.opts.imageSize, ...
                                         state.opts.scaleFactor, ... 
                                         0.1, 5, ...
                                         state.opts.updatePosThre);
        negatives = Sampler.getNegatives('uniform', trkPos, ...
                                         state.opts.updateNumNeg, ...
                                         state.opts.imageSize, ...
                                         state.opts.scaleFactor, ...
                                         2, 5, ...
                                         state.opts.updateNegThre, ...
                                         false);
            
        posIndex = 1:size(positives, 1);
        negIndex = (1:size(negatives,1)) + size(positives,1);
        samples = [positives; negatives];
            
        patches = Utility.getPatches(image, samples, state.opts);
        features = Network.forward(state.cnet.feat, {patches - 128}, state.opts, 'feature');
        state.cnetPos{end+1} = features(:, :, :, posIndex);
        state.cnetNeg{end+1} = features(:, :, :, negIndex);

        % for locNet
        [patches, labels, instanceWeights] = ...
            DLST.getSearchRegions(image, positives(1:10:end, :), state.opts);
        features = Network.forward(state.lnet.feat, {patches - 128}, state.opts, 'feature');
        features = bsxfun(@times, features, state.cosWindow);
        state.lnetFeats{end+1} = features;
        state.lnetLabel{end+1} = labels;
        state.lnetInstW{end+1} = instanceWeights;
            
        state.success = [state.success, state.frame];
        if(numel(state.success) > state.opts.updateLongPeriod)
            range = state.success(end - state.opts.updateLongPeriod);
            state.cnetPos{range} = single([]);
            state.lnetFeats{range} = single([]);
            state.lnetLabel{range} = single([]);
            state.lnetInstW{range} = single([]);   
        end
            
        if(numel(state.success) > state.opts.updateShortPeriod)
            state.cnetNeg{state.success(end - state.opts.updateShortPeriod)} = single([]);
        end
    else
        state.cnetPos{end+1} = single([]);
        state.cnetNeg{end+1} = single([]);
        state.lnetFeats{end+1} = single([]);
        state.lnetLabel{end+1} = single([]);
        state.lnetInstW{end+1} = single([]);  
    end
    
    % Network update
    if ((mod(state.frame, state.opts.updateInterval) == 0 || trkScore < 0))
        numSucess = numel(state.success);
        if (trkScore < 0) % short-term update
            range = state.success(max(1, numSucess - state.opts.updateShortPeriod+1) : numSucess);
        else % long-term update
            range = state.success(max(1, numSucess - state.opts.updateLongPeriod+1) : numSucess);
        end
        posFeats = cat(4, state.cnetPos{range});
        negFeats = cat(4, state.cnetNeg{state.success(max(1, end - state.opts.updateShortPeriod+1):end)});
        
        state.cnet.trac = Network.trainCNet(state.cnet.trac, [], ...
                                            {posFeats}, {negFeats}, ...
                                            state.opts, ...
                                            'maxIters', state.opts.updateMaxIters, ...
                                            'learningRate', state.opts.learningRate);
            
        features = cat(4, state.lnetFeats{range});
        labels = cat(4, state.lnetLabel{range});
        instanceWeights = cat(4, state.lnetInstW{range});
        state.lnet.trac = Network.trainLNet(state.lnet.trac, [], ...
                                            features, labels, instanceWeights, ...
                                            state.opts, ...
                                            'maxIters', state.opts.updateMaxIters, ...
                                            'learningRate', state.opts.learningRate);
    end
    
    state.region = currTrkPos;
end